==> avaritia-forge-1.20.1-1.3.9.3-release-sources.jar: committee/nova/mods/avaritia/Res.java <==
package committee.nova.mods.avaritia;

import net.minecraft.client.renderer.texture.TextureAtlasSprite;
import net.minecraft.resources.ResourceLocation;

/**
 * @Project: Avaritia
 * @author cnlimiter
 * @CreateTime: 2025/5/21 00:33
 * @Description:
 */
public class Res {
    public static final ResourceLocation DRAGON_FIREBALL = ResourceLocation.tryParse("textures/entity/enderdragon/dragon_fireball.png");
    public static final ResourceLocation VOID = Const.rl("textures/entity/void.png");
    public static final ResourceLocation VOID_HALO = Const.rl("textures/entity/void_halo.png");
    public static final ResourceLocation HEAVEN_ARROW = Const.rl("textures/entity/heavenarrow.png");
    public static final ResourceLocation BLADE_SLASH = Const.rl("textures/entity/blade_slash.png");
    public static final ResourceLocation INFINITY_ELYTRA = Const.rl("textures/entity/infinity_elytra.png");
    public static final ResourceLocation INFINITY_GOLEM = Const.rl("textures/entity/iron_golem.png");
    public static final ResourceLocation SUN_PRO_TEX = Const.rl("textures/entity/sun_pro.png");
    public static final ResourceLocation RAIN_PRO_TEX = Const.rl("textures/entity/rain_pro.png");
    public static final ResourceLocation STORM_PRO_TEX = Const.rl("textures/entity/storm_pro.png");
    public static final ResourceLocation TRIDENT_TEX = Const.rl("textures/entity/infinity_trident_model.png");
    public static final ResourceLocation SHIELD_TEX = Const.rl("textures/item/tools/infinity_shield/layer_0.png");

    public static final ResourceLocation NEUTRON_HORSE_ARMOR = Const.rl("textures/item/armor/horse/neutron_horse_armor.png");

    public static final ResourceLocation EYE_TEX = Const.rl("textures/models/armor/infinity_armor_eyes.png");
    public static final ResourceLocation WING_TEX = Const.rl("textures/models/armor/infinity_armor_wing.png");
    public static final ResourceLocation WING_GLOW_TEX = Const.rl("textures/models/armor/infinity_armor_wing_glow.png");

    public static final ResourceLocation INFINITY_CLOCK_TIME_TEX = Const.rl("textures/gui/machine/infinity_clock_time.png");
    public static final ResourceLocation NEUTRON_COLLECTOR_TEX = Const.rl("textures/gui/machine/neutron_collector.png");
    public static final ResourceLocation NEUTRON_COMPRESSOR_TEX = Const.rl("textures/gui/machine/neutron_compressor.png");
    public static final ResourceLocation SIDE_CONFIG_TEX = Const.rl("textures/gui/machine/side_config.png");
    public static final ResourceLocation EXTREME_ANVIL_TEX = Const.rl("textures/gui/machine/extreme_anvil_gui.png");
    public static final ResourceLocation GENERIC_243_TEX = Const.rl("textures/gui/chest/generic_243.png");
    public static final ResourceLocation NEUTRON_RING_TEX = Const.rl("textures/gui/chest/neutron_ring.png");
    public static final ResourceLocation EXTREME_SMITHING_TEX = Const.rl("textures/gui/machine/extreme_smithing_table_gui.png");
    public static final ResourceLocation BLACK_HOLE_CHANNEL_PANEL = Const.rl("textures/gui/chest/channel_panel.png");
    public static final ResourceLocation BLACK_HOLE_CHANNEL_SELECT = Const.rl("textures/gui/chest/channel_select.png");
    public static final ResourceLocation INFINITY_CHEST_TEX = Const.rl("textures/gui/chest/infinity_chest.png");
    public static final ResourceLocation ARC_TEX = Const.rl("textures/effect/line_segment.png");

    public static TextureAtlasSprite ARMOR_MASK;
    public static TextureAtlasSprite ARMOR_MASK_INV;
    public static TextureAtlasSprite ARMOR_WING_MASK;
}

==> avaritia-forge-1.20.1-1.3.9.4-release-sources.jar: committee/nova/mods/avaritia/Res.java <==
package committee.nova.mods.avaritia;

import net.minecraft.client.renderer.texture.TextureAtlasSprite;
import net.minecraft.resources.ResourceLocation;

/**
 * @Project: Avaritia
 * @author cnlimiter
 * @CreateTime: 2025/5/21 00:33
 * @Description:
 */
public class Res {
    public static final ResourceLocation DRAGON_FIREBALL = ResourceLocation.tryParse("textures/entity/enderdragon/dragon_fireball.png");
    public static final ResourceLocation VOID = Const.rl("textures/entity/void.png");
    public static final ResourceLocation VOID_HALO = Const.rl("textures/entity/void_halo.png");
    public static final ResourceLocation HEAVEN_ARROW = Const.rl("textures/entity/heaven_arrow.png");
    public static final ResourceLocation NEUTRON_ARROW = Const.rl( "textures/entity/neutron_arrow.png");
    public static final ResourceLocation BURNING_ARROW = Const.rl("textures/entity/burning_arrow.png");
    public static final ResourceLocation BLADE_SLASH = Const.rl("textures/entity/blade_slash.png");
    public static final ResourceLocation INFINITY_ELYTRA = Const.rl("textures/entity/infinity_elytra.png");
    public static final ResourceLocation INFINITY_GOLEM = Const.rl("textures/entity/iron_golem.png");
    public static final ResourceLocation SUN_PRO_TEX = Const.rl("textures/entity/sun_pro.png");
    public static final ResourceLocation RAIN_PRO_TEX = Const.rl("textures/entity/rain_pro.png");
    public static final ResourceLocation STORM_PRO_TEX = Const.rl("textures/entity/storm_pro.png");
    public static final ResourceLocation TRIDENT_TEX = Const.rl("textures/entity/infinity_trident_model.png");
    public static final ResourceLocation SHIELD_TEX = Const.rl("textures/item/tools/infinity_shield/layer_0.png");

    public static final ResourceLocation NEUTRON_HORSE_ARMOR = Const.rl("textures/item/armor/horse/neutron_horse_armor.png");

    public static final ResourceLocation EYE_TEX = Const.rl("textures/models/armor/infinity_armor_eyes.png");
    public static final ResourceLocation WING_TEX = Const.rl("textures/models/armor/infinity_armor_wing.png");
    public static final ResourceLocation WING_GLOW_TEX = Const.rl("textures/models/armor/infinity_armor_wing_glow.png");

    public static final ResourceLocation INFINITY_CLOCK_TIME_TEX = Const.rl("textures/gui/machine/infinity_clock_time.png");
    public static final ResourceLocation NEUTRON_COLLECTOR_TEX = Const.rl("textures/gui/machine/neutron_collector.png");
    public static final ResourceLocation NEUTRON_COMPRESSOR_TEX = Const.rl("textures/gui/machine/neutron_compressor.png");
    public static final ResourceLocation SIDE_CONFIG_TEX = Const.rl("textures/gui/machine/side_config.png");
    public static final ResourceLocation EXTREME_ANVIL_TEX = Const.rl("textures/gui/machine/extreme_anvil_gui.png");
    public static final ResourceLocation GENERIC_243_TEX = Const.rl("textures/gui/chest/generic_243.png");
    public static final ResourceLocation NEUTRON_RING_TEX = Const.rl("textures/gui/chest/neutron_ring.png");
    public static final ResourceLocation EXTREME_SMITHING_TEX = Const.rl("textures/gui/machine/extreme_smithing_table_gui.png");
    public static final ResourceLocation BLACK_HOLE_CHANNEL_PANEL = Const.rl("textures/gui/chest/channel_panel.png");
    public static final ResourceLocation BLACK_HOLE_CHANNEL_SELECT = Const.rl("textures/gui/chest/channel_select.png");
    public static final ResourceLocation INFINITY_CHEST_TEX = Const.rl("textures/gui/chest/infinity_chest1.png");
    public static final ResourceLocation ARC_TEX = Const.rl("textures/effect/line_segment.png");

    public static TextureAtlasSprite ARMOR_MASK;
    public static TextureAtlasSprite ARMOR_MASK_INV;
    public static TextureAtlasSprite ARMOR_WING_MASK;
}
